@@ -15,7 +15,9 @@ else:
 
     import abc
     import reprlib
-    from typing import Any, Callable, Optional, Union
+    import typing as ty
+    from collections.abc import Callable
+    from typing import Any, Optional, Union
 
     class DBCMeta(abc.ABCMeta):  # type: ignore
         pass
@@ -29,33 +31,35 @@ else:
     # pylint: disable=unused-argument
 
     def require(  # type: ignore[no-redef,misc]
-        condition: Callable[..., Any],
+        condition: ty.Callable[..., Any],  # noqa: PEA001
         description: Optional[str] = None,
         a_repr: reprlib.Repr = None,
         enabled: bool = __debug__,
-        error: Optional[Union[Callable[..., Exception], type]] = None,
+        error: Optional[Union[ty.Callable[..., Exception], type]] = None,  # noqa: PEA001
     ) -> Callable:  # type: ignore[type-arg]
         return lambda x: x
 
     def snapshot(  # type: ignore[no-redef,misc]
-        capture: Callable[..., Any], name: Optional[str] = None, enabled: bool = __debug__
+        capture: ty.Callable[..., Any],  # noqa: PEA001
+        name: Optional[str] = None,
+        enabled: bool = __debug__,
     ) -> Callable:  # type: ignore[type-arg]
         return lambda x: x
 
     def ensure(  # type: ignore[no-redef,misc]
-        condition: Callable[..., Any],
+        condition: ty.Callable[..., Any],  # noqa: PEA001
         description: Optional[str] = None,
         a_repr: reprlib.Repr = None,
         enabled: bool = __debug__,
-        error: Optional[Union[Callable[..., Exception], type]] = None,
+        error: Optional[Union[ty.Callable[..., Exception], type]] = None,  # noqa: PEA001
     ) -> Callable:  # type: ignore[type-arg]
         return lambda x: x
 
     def invariant(  # type: ignore[no-redef,misc]
-        condition: Callable[..., Any],
+        condition: ty.Callable[..., Any],  # noqa: PEA001
         description: Optional[str] = None,
         a_repr: reprlib.Repr = None,
         enabled: bool = __debug__,
-        error: Optional[Union[Callable[..., Exception], type]] = None,
+        error: Optional[Union[ty.Callable[..., Exception], type]] = None,  # noqa: PEA001
     ) -> Callable:  # type: ignore[type-arg]
         return lambda x: x
