@@ -44,7 +44,6 @@ from rflx.ada import (
     InstantiationUnit,
     Last,
     Less,
-    ModularType,
     Not,
     NotIn,
     Number,
@@ -95,9 +94,7 @@ from rflx.model import (
     Integer,
     Message,
     Model,
-    ModularInteger,
     Opaque,
-    RangeInteger,
     Refinement,
     Scalar,
     Sequence,
@@ -536,13 +533,11 @@ class Generator:
             ),
             self._executor.submit(parser_generator.create_verify_message_procedure, message),
             self._executor.submit(parser_generator.create_present_function),
-            self._executor.submit(parser_generator.create_structural_valid_function),
+            self._executor.submit(parser_generator.create_well_formed_function),
             self._executor.submit(parser_generator.create_valid_function),
             self._executor.submit(parser_generator.create_incomplete_function),
             self._executor.submit(parser_generator.create_invalid_function),
-            self._executor.submit(
-                parser_generator.create_structural_valid_message_function, message
-            ),
+            self._executor.submit(parser_generator.create_well_formed_message_function, message),
             self._executor.submit(parser_generator.create_valid_message_function, message),
             self._executor.submit(parser_generator.create_incomplete_message_function),
             self._executor.submit(
@@ -713,11 +708,8 @@ class Generator:
         if isinstance(field_type, (Integer, Enumeration)):
             unit.declaration_context.append(WithClause(self._prefix * const.TYPES))
 
-        if isinstance(field_type, ModularInteger):
-            unit += UnitPart(modular_types(field_type))
-            unit += self._integer_functions(field_type)
-        elif isinstance(field_type, RangeInteger):
-            unit += UnitPart(range_types(field_type))
+        if isinstance(field_type, Integer):
+            unit += UnitPart(integer_types(field_type))
             unit += self._integer_functions(field_type)
         elif isinstance(field_type, Enumeration):
             unit += UnitPart(enumeration_types(field_type))
@@ -1419,7 +1411,7 @@ class Generator:
             conditions.extend(
                 [
                     expr.Call(
-                        pdu_identifier * "Structural_Valid",
+                        pdu_identifier * "Well_Formed",
                         [
                             expr.Variable(pdu_context),
                             expr.Variable(pdu_identifier * refinement.field.affixed_name),
@@ -1471,17 +1463,7 @@ def create_file(filename: Path, content: str) -> None:
     filename.write_text(content)
 
 
-def modular_types(integer: ModularInteger) -> list[Declaration]:
-    return [
-        ModularType(
-            integer.name,
-            integer.modulus.ada_expr(),
-            aspects=[SizeAspect(integer.size_expr.ada_expr())],
-        )
-    ]
-
-
-def range_types(integer: RangeInteger) -> list[Declaration]:
+def integer_types(integer: Integer) -> list[Declaration]:
     return [
         RangeType(
             integer.name,
