@@ -30,9 +30,7 @@ from .type_ import (  # noqa: F401
     Composite as Composite,
     Enumeration as Enumeration,
     Integer as Integer,
-    ModularInteger as ModularInteger,
     Opaque as Opaque,
-    RangeInteger as RangeInteger,
     Scalar as Scalar,
     Sequence as Sequence,
     Type as Type,
