@@ -903,15 +903,28 @@ def create_modular(
     _workers: int,
     _cache: Cache,
     filename: Path,
-) -> Optional[model.Type]:
+) -> None:
     assert isinstance(modular, lang.ModularTypeDef)
-    result = model.ModularInteger(
-        identifier,
-        create_math_expression(error, modular.f_mod, filename),
-        type_location(identifier, modular),
+    modulus = create_math_expression(error, modular.f_mod, filename).simplified()
+    assert isinstance(modulus, expr.Number)
+    upper = int(modulus) - 1
+    error.extend(
+        [
+            (
+                "modular integer types are not supported",
+                Subsystem.PARSER,
+                Severity.ERROR,
+                type_location(identifier, modular),
+            ),
+            (
+                f'use "type {identifier.name} is range 0 .. {upper}'
+                f' with Size => {upper.bit_length()}" instead',
+                Subsystem.PARSER,
+                Severity.INFO,
+                type_location(identifier, modular),
+            ),
+        ]
     )
-    error.extend(result.error)
-    return result
 
 
 def create_range(
@@ -939,7 +952,7 @@ def create_range(
             ]
         )
     size = create_math_expression(error, rangetype.f_size.f_value, filename)
-    result = model.RangeInteger(
+    result = model.Integer(
         identifier,
         create_math_expression(error, rangetype.f_first, filename),
         create_math_expression(error, rangetype.f_last, filename),
@@ -1194,6 +1207,13 @@ def create_message_structure(
 
     structure: list[model.Link] = []
 
+    field_identifiers = {
+        # Do not store errors in `error` object as this would result in duplicate error messages
+        # from the invocation of create_message_types
+        i: create_id(RecordFluxError(), field.f_identifier, filename)
+        for i, field in enumerate(fields.f_fields)
+    }
+
     if fields.f_initial_field:
         structure.append(
             model.Link(
@@ -1205,18 +1225,13 @@ def create_message_structure(
         structure.append(
             model.Link(
                 model.INITIAL,
-                model.Field(create_id(error, fields.f_fields[0].f_identifier, filename)),
-                location=node_location(fields.f_fields[0].f_identifier, filename),
+                model.Field(field_identifiers[0]),
+                location=field_identifiers[0].location,
             )
         )
 
     for i, field in enumerate(fields.f_fields):
-        source_node = (
-            model.Field(create_id(error, field.f_identifier, filename))
-            if field.f_identifier
-            else model.INITIAL
-        )
-        field_identifier = create_id(error, field.f_identifier, filename)
+        source_node = model.Field(field_identifiers[i]) if field.f_identifier else model.INITIAL
         if field.f_identifier.text.lower() == "message":
             error.extend(
                 [
@@ -1224,18 +1239,13 @@ def create_message_structure(
                         'reserved word "Message" used as identifier',
                         Subsystem.PARSER,
                         Severity.ERROR,
-                        field_identifier.location,
+                        field_identifiers[i].location,
                     )
                 ],
             )
-            continue
 
         if len(field.f_thens) == 0:
-            target_id = (
-                create_id(error, fields.f_fields[i + 1].f_identifier, filename)
-                if i + 1 < len(fields.f_fields)
-                else None
-            )
+            target_id = field_identifiers[i + 1] if i + 1 < len(fields.f_fields) else None
             target_node = model.Field(target_id) if target_id else model.FINAL
             structure.append(
                 model.Link(
@@ -1262,12 +1272,14 @@ def create_message_structure(
                 continue
             structure.append(model.Link(source_node, *extract_then(then)))
 
-        if error.check():
+        if error.errors:
             continue
 
-        merge_field_aspects(error, field_identifier, structure, *extract_aspect(field.f_aspects))
+        merge_field_aspects(
+            error, field_identifiers[i], structure, *extract_aspect(field.f_aspects)
+        )
         merge_field_condition(
-            field_identifier,
+            field_identifiers[i],
             structure,
             create_bool_expression(error, field.f_condition, filename)
             if field.f_condition
@@ -1641,7 +1653,7 @@ def create_refinement(
 
     refinement_id = model.Field(create_id(error, refinement.f_field, filename))
 
-    if error.check():
+    if error.errors:
         return None
 
     result = model.Refinement(
